==> haskell-isomorphism-class-0.1.0.11-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 isomorphism-class
version:              0.1.0.11
visibility:           public
id:                   isomorphism-class-0.1.0.11-Cbi3178rWQcIBq8g0T15TD
key:                  isomorphism-class-0.1.0.11-Cbi3178rWQcIBq8g0T15TD
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  40c5da8cf54e3998f7a34e5e724d50ad
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.2.8/site-local/isomorphism-class-0.1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/isomorphism-class-0.1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.0.11-Cbi3178rWQcIBq8g0T15TD
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN text-1.2.5.0
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-isomorphism-class-0.1.0.11-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-isomorphism-class.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 isomorphism-class
version:              0.1.0.11
visibility:           public
id:                   isomorphism-class-0.1.0.11-6qe4BF36Qfu8uSOVyO45i6
key:                  isomorphism-class-0.1.0.11-6qe4BF36Qfu8uSOVyO45i6
license:              MIT
copyright:            (c) 2022 Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/isomorphism-class
synopsis:             Isomorphism typeclass solving the conversion problem
description:          Lawful typeclass for lossless conversion between types.
category:             Conversion
abi:                  5d7fc78218581c4bb0f1a7265a180716
exposed:              True
exposed-modules:      IsomorphismClass
hidden-modules:
    IsomorphismClass.Prelude IsomorphismClass.TextCompat.Array

import-dirs:          /usr/lib/ghc-9.2.8/site-local/isomorphism-class-0.1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/isomorphism-class-0.1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-isomorphism-class
hs-libraries:         HSisomorphism-class-0.1.0.11-6qe4BF36Qfu8uSOVyO45i6
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN text-1.2.5.0
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:
    /usr/share/doc/haskell-isomorphism-class/html/isomorphism-class.haddock

haddock-html:         /usr/share/doc/haskell-isomorphism-class/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
